<?xml version="1.0" encoding="UTF-8"?>

<#import "common_module_traversal_utils.ftl" as utils>
<#import "macros_common_general.ftl" as com>
<#import "common_module_front_page_docbook.ftl" as fp>

<#-- Initialize common variables -->
<@com.initializeMainVariables/>

<#assign locale = "en" />
<#assign sysDateTime = .now>

<#-- Root entity -->
<#assign rootEntity = entity.root>

<#-- Define the main macro to be used to retrieve output by the traversal approach -->
<#assign mainMacroName = "printAnnotationsForDocument"/>
<#assign mainMacroArgs = ['sectionDoc', 'sectionNode', 'entityDocument', 'level']/>

<#-- Make global the macroCall as well as each macro used in it -->
<#global mainMacroCall="<@" + mainMacroName + " " + mainMacroArgs?join(" ") + "/>"/>
<#global printAnnotationsForDocument=printAnnotationsForDocument/>

<#-- intialise list for annex of annotations -->
<#assign annexForAnnotationInformation = []/>

<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

    <#-- Get front page -->
    <@fp.getFrontPage _subject _dossierHeader "List of Annotations"/>


    <#-- Chapters -->
    <chapter label="1">
        <title role="HEAD-1">List of annotations</title>

      <#-- Maxloop sets the limit at which the component hierarchy is travered -->
      <table border="1">
        <title>Table of annotations</title>
          <col width="12.5%" />
          <col width="12.5%" />
          <col width="12.5%" />
          <col width="12.5%" />
          <col width="12.5%" />
          <col width="12.5%" />
          <col width="12.5%" />
          <col width="12.5%" />
          <tbody>
            <tr>								
              <th colspan="1"><?dbfo bgcolor="#d6eaf8" ?><emphasis role="bold">Section name and number</emphasis></th>
              <th colspan="1"><?dbfo bgcolor="#d6eaf8" ?><emphasis role="bold">Document name</emphasis></th>          
              <th colspan="1"><?dbfo bgcolor="#d6eaf8" ?><emphasis role="bold">Document uuid</emphasis></th>
              <th colspan="1"><?dbfo bgcolor="#F9C514" ?><emphasis role="bold">Annotation organisation and Evaluation attachment name</emphasis></th>
              <th colspan="1"><?dbfo bgcolor="#F9C514" ?><emphasis role="bold">Annotation name</emphasis></th>
              <th colspan="1"><?dbfo bgcolor="#F9C514" ?><emphasis role="bold">Annotation status and type</emphasis></th>
              <th colspan="1"><?dbfo bgcolor="#F9C514" ?><emphasis role="bold">Annotation agreement</emphasis></th>          
              <th colspan="1"><?dbfo bgcolor="#F9C514" ?><emphasis role="bold">Annex of annotation</emphasis></th>       
            </tr>

            <#-- Traversal approach: prints one row per claim -->
            <@utils.traversal rootEntity 8/>

          </tbody>
      </table>
  </chapter>

  <chapter label="2">
      <title role="HEAD-1">Annex of Information on Annotations</title>			
        <para>
          <@annotationsAnnex annexForAnnotationInformation/>
        </para>
  </chapter>

</book>

<#----------------------------------------------->
<#-- Macro and function definitions start here -->
<#----------------------------------------------->
<#macro printAnnotationsForDocument sectionDoc sectionNode entityDocument level>

  <#if level == 0>

    <#local sectionName = "">
    <#if sectionNode?has_content>
      <#if sectionNode.number?has_content>
        <#local sectionName = sectionNode.number + " ">
      </#if>
      <#local sectionName = sectionName + sectionNode.title>
    </#if>

    <#local sectionDocType = sectionDoc.documentType>

    <#if !utils.isEntityDocument(sectionDoc)>
      <#local sectionDocType = sectionDocType + "." + sectionDoc.documentSubType>
    </#if>

    <#-- The web URL pointing to the document -->
    <#local docUrl=utils.getDocumentUrl(sectionDoc) />

    <#-- Get the annotations of the document and print a row for each of them -->
    <#local annotationKeys = sectionDoc.annotations />
    <#if annotationKeys?has_content>
      <#list annotationKeys as key>
        <#local annotation = iuclid.getDocumentForKey(key) />
        <#local annotationStatus = annotation.AdminInfo.AnnotationStatus />
        <#local annotationAgreement = annotation.EvalInfo.AgreementWithApplicantsSummary />

          <@tableOutput annotation annotationStatus annotationAgreement sectionName sectionDoc docUrl />

      </#list>
    </#if>
  </#if>
</#macro>

<#macro tableOutput annotation annotationStatus annotationAgreement sectionName sectionDoc docUrl>

 <tr>  
     <#-- IUCLID Section name and number -->
    <td>
      <@com.text sectionName />
    </td>
    
    <#-- IUCLID document name -->
    <td>
        <ulink url="${docUrl}">
          <@com.text sectionDoc.name />
        </ulink> 
    </td>

     <#-- IUCLID document uuid -->
    <td>
        <@com.text sectionDoc.documentKey.uuid />
    </td>

    <#-- annotation organisation and evaluation attachment name -->
    <td><para>

        <#if annotation.AdminInfo.Authority?has_content>        
        <para><emphasis role="bold">Name of organisation:</emphasis> <@com.text annotation.AdminInfo.Authority/></para>
        </#if>

        <#if annotation.AttachedRegulatoryAuthoritiesEvaluation.Evaluation?has_content>
        <para><emphasis role="bold">Evaluation attachment name:</emphasis> <@annotationAttachedEvaluationName annotation/></para>
        </#if>

        </para>
    </td>
    
    <#-- annotation name -->									
    <td>   
    <#if annotation.AdminInfo.Name?has_content>
      <@com.text annotation.AdminInfo.Name/>      
    </#if>
    
    <#assign historyList = (getFirstHistoryOnlyOfAnnotation(annotation))!"" />
    <#if historyList?has_content>
      <para><emphasis role="bold">Annotation Last updated:</emphasis> ${historyList.date}</para>
    </#if>    
    </td>

     <#-- annotation status and annotation type -->
     <td>
      <#if annotationStatus?has_content>
        <emphasis role="bold">Annotation status:</emphasis> <@com.picklist annotationStatus />
      </#if>

      <para>
        <#if annotation.AdminInfo.AnnotationType?has_content>
        <emphasis role="bold">Annotation type:</emphasis> <@com.picklist annotation.AdminInfo.AnnotationType />
        </#if>
      </para>
    </td>

    <#-- annotation agreement  -->
    <td>
      <#if annotationAgreement?has_content>
        <@com.picklist annotationAgreement/>
      </#if>
    </td>

    <#-- annotation annex  -->
    <td>
      <#assign annexForAnnotationInformation = annexForAnnotationInformation + [annotation] />
      <para><command linkend="annotationLink">More annotation information available in the <phrase role="blue">annex</phrase></command></para>
    </td>

  </tr>
</#macro>

<#macro annotationsAnnex annexForAnnotationInformation>
	
  <para xml:id="annotationLink"></para>
	
  <#list annexForAnnotationInformation as annotations>		
		
		<informaltable Frame="sides">
		<col width="50%" />
		<col width="50%" />
			<tbody>	
				<tr>
					<td><?dbfo bgcolor="#EEEEEE" ?>
					<para><emphasis role="HEAD-WoutNo">Administrative data</emphasis></para>
						<para><emphasis role="bold"><phrase role="blue">
						Additional annotation information for </phrase><phrase role="red"><@com.text annotations.AdminInfo.Name/></phrase></emphasis><para><emphasis role="bold">Annotation UUID:</emphasis><@com.text annotations.documentKey.uuid/></para></para>
						<#assign status><@annotationStatus annotations/></#assign>
						<#if status?has_content>
						<para><emphasis role="bold">Annotation status: </emphasis><@annotationStatus annotations/></para>
						</#if>
						<#assign annotationBasicRemarks><@annotationRemarks annotations/></#assign>
						<#if annotationBasicRemarks?has_content>
						<para><emphasis role="bold">Annotation remarks:</emphasis></para> <@annotationRemarks annotations/>
						</#if>
						<#assign annotationBasicAttachment><@annotationAttachedEvaluationName annotations/></#assign>
						<#if annotationBasicAttachment?has_content>
						<para><emphasis role="bold">Evaluation attachment name:</emphasis> <@annotationAttachedEvaluationName annotations/></para>
						</#if>	
					</td>
					
					<td><?dbfo bgcolor="#D5FFDF" ?>
					<para><emphasis role="HEAD-WoutNo">Evaluation data</emphasis></para>
						<#assign annotationDataRemarks><@annotationDatasetRemarks annotations/></#assign>
						<#if annotationDataRemarks?has_content>
						<para><emphasis role="bold">Annotation remarks:</emphasis></para><@annotationDatasetRemarks annotations/>
						</#if>
						<#assign annotationDatasetCross><@annotationDatasetCrossReference annotations/></#assign>
						<#if annotationDatasetCross?has_content>
						<para><emphasis role="bold">Annotation cross reference:</emphasis> <@annotationDatasetCrossReference annotations/></para>
						</#if>
						<#assign annotationDataExecSummary><@annotationDatasetExecSummary annotations/></#assign>
						<#if annotationDataExecSummary?has_content>
						<para><emphasis role="bold">Annotations executive summary:</emphasis></para><para><@annotationDatasetExecSummary annotations/></para>
						</#if>						
						<#assign annotationAttachments><@attachmentName annotations/></#assign>
						<#if annotationAttachments?has_content>
						<para><emphasis role="bold">Other attachments linked to the annotation via the 'IUCLID Information panel':</emphasis></para>
						<para><@attachmentName annotations /></para>
						</#if>
					</td>
				</tr>
			</tbody>
		</informaltable>
	</#list>

</#macro>

<#macro annotationAttachedEvaluationName annotation>

		<#if annotation?has_content>
			<#list annotation.AttachedRegulatoryAuthoritiesEvaluation.Evaluation as attachments>
			<#if attachments?has_content>
			<#assign attachment = iuclid.getMetadataForAttachment(attachments) />
				<#if attachment?has_content>			
				<para>${attachment.filename}</para>
        <para>(size: ${attachment.size} file type: ${attachment.mediaType})</para>
					<#if attachment.remarks?has_content>
						<emphasis role="bold">Remarks for attached Evaluation:</emphasis> ${attachment.remarks}
					</#if>
				</#if>
				<#if attachments_has_next??><?linebreak?></#if>
			</#if>
			</#list>
		</#if>

</#macro>

<#macro annotationStatus annotations>
		<#if annotations?has_content>
		<@com.picklist annotations.AdminInfo.AnnotationStatus/>
			<#else/>
			No Annotation Status is provided for this annotation
		</#if>
	
</#macro>

<#function getFirstHistoryOnlyOfAnnotation annotation>

  <#local historyList = iuclid.getHistoryForDocumentKey(annotation.documentKey) />
    
  <#if !(annotation)?has_content>
    <#return [] />
  </#if>
  
  <#if !(historyList)?has_content>
    <#return [] />
  </#if>
  
  <#if historyList?has_content>		
    <#list historyList as history>	
      <#if !(history)?has_content>
        <#return [] />	
        <#else/>
          <#return historyList[0] />					
      </#if>
    </#list>
  </#if>		
</#function>

<#assign annexForAnnotationInformation = [] />
<#macro annexForAnnotations annotation>
  <#compress>
          <#if annotation?has_content>	
            <#assign annexForAnnotationInformation = annexForAnnotationInformation + [annotation] />
            <para><command linkend="annotationLink">More annotation information available in the <phrase role="blue">annex</phrase></command></para>
          </#if>
  </#compress>
</#macro>

<#macro annotationNameOfAuthority annotations>
		<#if annotations?has_content>
		${annotations.AdminInfo.Authority}
			<#else/>
			No Authority or Organisation name is provided for this annotation
		</#if>
	
</#macro>

<#macro annotationRemarks annotations>
<#if annotations?has_content>
		<@com.richText annotations.AdminInfo.Remarks/>
			<#else/>
			No Remarks are provided for this annotation
		</#if>
</#macro>

<#macro annotationDatasetDataWaiving annotations>
<#compress>
		<#if annotations?has_content>
		<@com.picklist annotations.EvalInfo.DataWaiverAcceptable/>
		</#if>
</#compress>
</#macro>


<#macro annotationDatasetReliability annotations>
<#compress>
<#if annotations?has_content>
		<@com.picklist annotations.EvalInfo.Reliability/>
		</#if>
</#compress>
</#macro>


<#macro annotationDatasetRemarks annotations>
<#compress>

		<#if annotations?has_content>
		<@com.text annotations.EvalInfo.Remarks/>
		</#if>
	
</#compress>
</#macro>


<#macro annotationDatasetCrossReference annotations>
<#compress>
		<#if annotations?has_content>
		<@com.text annotations.EvalInfo.CrossReferenceToOtherStudy/>
		</#if>
		
</#compress>
</#macro>


<#macro annotationDatasetConclusions annotations>
<#compress>
<#if annotations?has_content>
		<@com.text annotations.EvalInfo.Conclusions/>
		</#if>
</#compress>
</#macro>


<#macro annotationDatasetExecSummary annotations>
<#compress>

		<#if annotations?has_content>
		<@com.richText annotations.EvalInfo.ExecutiveSummary/>
		</#if>
		
</#compress>
</#macro>


<#macro attachmentName annotations>
<#compress>
	<#if annotations?has_content>
		<#list annotations.attachments as annotationAttachment>
		<#assign attachmentData = iuclid.getMetadataForAttachment(annotationAttachment) />
			<#if attachmentData?has_content>
				<#escape x as x?html>${attachmentData.filename}</#escape>
			</#if>
		</#list>
	</#if>

</#compress>
</#macro>





